@@ -13,7 +13,7 @@
   # Sys.setenv() replaces Sys.putenv() from R v2.5.0. Code for migration.
   if (!exists("Sys.setenv", mode="function", envir=baseenv())) {
     # To please R CMD check on R (>= 2.15.0)
-    Sys.putenv <- NULL; rm("Sys.putenv");
+    Sys.putenv <- NULL; rm(list="Sys.putenv");
     assign("Sys.setenv", Sys.putenv, pos=pos);
   }
 
